<?php
/**
 * @file
 * Contains \Drupal\mollie_payment\Form\TestForm.
 */

namespace Drupal\mollie_payment\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\mollie_payment\Entity\MollieProfile;
use Mollie_API_Client;

/**
 * Defines a form to configure maintenance settings for this site.
 */
class TestForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormID() {
    return 'mollie_payment_test';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $mollie_profiles = MollieProfile::loadMultiple();

    $options = array('' => t('- Select a profile -'));
    foreach($mollie_profiles as $id => $mollie_profile) {
      $options[$mollie_profile->getApiKey()] = $mollie_profile->label();
    }

    $form['apiKey'] = array(
      '#title' => t('Mollie profile'),
      '#type' => 'select',
      '#options' => $options,
      '#default_value' => '',
    );

    $form['actions'] = array(
      'submit' => array(
        '#type' => 'submit',
        '#value' => t('Test'),
      )
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   *
   * @todo Proper exception handling. Plural messages.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $apiKey = $form_state->getValue('apiKey');

    if (empty($apiKey)) {
      drupal_set_message(t('You need to select a profile to test.'), 'error');
      return;
    }

    $mollie = new Mollie_API_Client;
    try {
      $mollie->setApiKey($apiKey);

      try {
        $issuers = $mollie->issuers->all();

        if (!$issuers) {
          drupal_set_message(t('Could not retrieve a list of issuers. The API key for the selected profile might be invalid.'),
            'warning');
          return;
        }

        $names = array();
        foreach ($issuers as $issuer) {
          $names[] = $issuer->name;
        }

        drupal_set_message(t('Found @count issuers: @issuers. Connection for the selected profile is working.', array(
          '@count' => count($names),
          '@issuers' => implode(', ', $names),
        )), 'status');
      } catch (Mollie_API_Exception $e) {
        drupal_set_message($e->getMessage(), 'error');
        return;
      }
    } catch (Mollie_API_Exception $e) {
      drupal_set_message($e->getMessage(), 'error');
      return;
    }
  }
}

?>